@@ -2,6 +2,7 @@ from django.contrib import admin
 from django.contrib.auth.admin import UserAdmin
 
 from .models import Profile
+from .forms import ProfileCreationForm
 
 
 def deactivate(modeladmin, request, queryset):
@@ -10,6 +11,8 @@ deactivate.short_description = "Deactivate selected users"
 
 
 class ProfileAdmin(UserAdmin):
+    add_form = ProfileCreationForm
+
     date_hierarchy = 'date_joined'
     list_filter = ('is_staff', 'is_superuser', 'is_active', 'groups', 'date_joined')
     list_display = ('username', 'display_name', 'first_name', 'last_name', 'email', 'is_active', 'is_staff')
